@@ -56,9 +56,9 @@ class _IPv4Constants:
 
 
 class Provider(BaseProvider):
-    safe_domain_names: ElementsType = ("example.org", "example.com", "example.net")
-    free_email_domains: ElementsType = ("gmail.com", "yahoo.com", "hotmail.com")
-    tlds: ElementsType = (
+    safe_domain_names: ElementsType[str] = ("example.org", "example.com", "example.net")
+    free_email_domains: ElementsType[str] = ("gmail.com", "yahoo.com", "hotmail.com")
+    tlds: ElementsType[str] = (
         "com",
         "com",
         "com",
@@ -70,7 +70,7 @@ class Provider(BaseProvider):
         "net",
         "org",
     )
-    hostname_prefixes: ElementsType = (
+    hostname_prefixes: ElementsType[str] = (
         "db",
         "srv",
         "desktop",
@@ -79,7 +79,7 @@ class Provider(BaseProvider):
         "email",
         "web",
     )
-    uri_pages: ElementsType = (
+    uri_pages: ElementsType[str] = (
         "index",
         "home",
         "search",
@@ -95,7 +95,7 @@ class Provider(BaseProvider):
         "privacy",
         "author",
     )
-    uri_paths: ElementsType = (
+    uri_paths: ElementsType[str] = (
         "app",
         "main",
         "wp-content",
@@ -109,7 +109,7 @@ class Provider(BaseProvider):
         "list",
         "explore",
     )
-    uri_extensions: ElementsType = (
+    uri_extensions: ElementsType[str] = (
         ".html",
         ".html",
         ".html",
@@ -120,7 +120,7 @@ class Provider(BaseProvider):
         ".jsp",
         ".asp",
     )
-    http_methods: ElementsType = (
+    http_methods: ElementsType[str] = (
         "GET",
         "HEAD",
         "POST",
@@ -132,32 +132,24 @@ class Provider(BaseProvider):
         "PATCH",
     )
 
-    user_name_formats: ElementsType = (
+    user_name_formats: ElementsType[str] = (
         "{{last_name}}.{{first_name}}",
         "{{first_name}}.{{last_name}}",
         "{{first_name}}##",
         "?{{last_name}}",
     )
-    email_formats: ElementsType = (
+    email_formats: ElementsType[str] = (
         "{{user_name}}@{{domain_name}}",
         "{{user_name}}@{{free_email_domain}}",
     )
-    url_formats: ElementsType = (
+    url_formats: ElementsType[str] = (
         "www.{{domain_name}}/",
         "{{domain_name}}/",
     )
-    uri_formats: ElementsType = (
-        "{{url}}",
-        "{{url}}{{uri_page}}/",
-        "{{url}}{{uri_page}}{{uri_extension}}",
-        "{{url}}{{uri_path}}/{{uri_page}}/",
-        "{{url}}{{uri_path}}/{{uri_page}}{{uri_extension}}",
-    )
-    image_placeholder_services: ElementsType = (
+    image_placeholder_services: ElementsType[str] = (
         "https://picsum.photos/{width}/{height}",
         "https://dummyimage.com/{width}x{height}",
         "https://placekitten.com/{width}/{height}",
-        "https://placeimg.com/{width}/{height}/any",
     )
 
     replacements: Tuple[Tuple[str, str], ...] = ()
@@ -592,7 +584,7 @@ class Provider(BaseProvider):
 
     def mac_address(self) -> str:
         mac = [self.generator.random.randint(0x00, 0xFF) for _ in range(0, 6)]
-        return ":".join(map(lambda x: "%02x" % x, mac))
+        return ":".join("%02x" % x for x in mac)
 
     def port_number(self, is_system: bool = False, is_user: bool = False, is_dynamic: bool = False) -> int:
         """Returns a network port number
@@ -625,9 +617,22 @@ class Provider(BaseProvider):
     def uri_extension(self) -> str:
         return self.random_element(self.uri_extensions)
 
-    def uri(self) -> str:
-        pattern: str = self.random_element(self.uri_formats)
-        return self.generator.parse(pattern)
+    def uri(self, schemes: Optional[List[str]] = None, deep: Optional[int] = None) -> str:
+        """
+        :param schemes: a list of strings to use as schemes, one will chosen randomly.
+            If None, it will generate http and https uris.
+            Passing an empty list will result in schemeless uri generation like "://domain.com/index.html".
+        :param deep: an integer specifying how many path components the URI should have..
+        :return: a random url string.
+        """
+        if schemes is None:
+            schemes = ["http", "https"]
+
+        pattern: str = f'{self.random_element(schemes) if schemes else ""}://{self.random_element(self.url_formats)}'
+        path = self.uri_path(deep=deep)
+        page = self.uri_page()
+        extension = self.uri_extension()
+        return f"{self.generator.parse(pattern)}{path}{page}{extension}"
 
     @slugify
     def slug(self, value: Optional[str] = None) -> str:
